<?php
/*
 * @package Joomla 4.0
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Yandex Map Component
 * @copyright Copyright (C) Aleksandr Ermakov - https://www.slyweb.ru
 */

namespace Slyweb\Component\Mapyandex\Administrator\Controller;

// No direct access
use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Controller\AdminController;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\Input\Input;

\defined('_JEXEC') or die('Restricted access');

class AllmapsController extends AdminController
{
    /**
     * Constructor.
     *
     * @param   array                $config   An optional associative array of configuration settings.
     * Recognized key values include 'name', 'default_task', 'model_path', and
     * 'view_path' (this list is not meant to be comprehensive).
     * @param   MVCFactoryInterface  $factory  The factory.
     * @param   CMSApplication       $app      The Application for the dispatcher
     * @param   Input                $input    Input
     *
     * @since   3.0
     */

    public function __construct($config = array(), MVCFactoryInterface $factory = null, $app = null, $input = null)
    {
        parent::__construct($config, $factory, $app, $input);

        $this->input = Factory::getApplication()->input;
        // An article edit form can come from the articles or featured view.
        // Adjust the redirect view on the value of 'return' in the request.
        if ($this->input->get('return') == 'featured') {
            $this->view_list = 'featured';
            $this->view_item = 'article&return=featured';
        }
    }
    /**
     * Proxy for getModel
     *
     * @param   string  $name    The model name. Optional.
     * @param   string  $prefix  The class prefix. Optional.
     * @param   array   $config  The array of possible config values. Optional.
     *
     * @return  \Joomla\CMS\MVC\Model\BaseDatabaseModel  The model.
     *
     * @since   1.6
     */
    public function getModel($name = 'Map', $prefix = 'Administrator', $config = array('ignore_request' => true))
    {

        return parent::getModel($name, $prefix, $config);
    }

    /**
     * display the edit form
     * @return void
     * @throws \Exception
     * @since   1.6
     */

	function allmaps()
	{
		$this->input->set('view', 'map');
		$this->input->set('layout', 'form');
		$this->input->set('hidemainmenu', 1);

		parent::display();
	}

	function edit()
	{
		$this->input->set('view', 'map');
		$this->input->set('layout', 'form');
		$this->input->set('hidemainmenu', 1);

		parent::display();
	}

	function ajaxit()
	{
		$this->input->set('view', 'map');
		$this->input->set('layout', 'form');
		$this->input->set('hidemainmenu', 1);

		parent::display();
	}

	function add()
	{
		$this->input->set('view', 'allmaps');
		$this->input->set('layout', 'form');
		$this->input->set('hidemainmenu', 1);

		parent::display();
	}

	/**
	 * save a record (and redirect to main page)
	 * @return void
     * @since   1.6
	 */
	function save()
	{
        /** @var \Joomla\Component\Mapyandex\Administrator\Model\AllmapsModel $model */
        $model = $this->getModel('allmaps', 'Administrator');

		if ($model->store()) {
			$msg = Text::_('COM_MAPYANDEX_SUCCESSADDNEW');
		} else {
			$msg = Text::_('COM_MAPYANDEX_ERRORADDNEW');
		}
			$link = 'index.php?option=com_mapyandex&view=allmaps';
			$this->setRedirect($link, $msg);
		// Check the table in so it can be edited.... we are done with it anyway
	}

	function apply()
	{
		$model = $this->getModel('map');

		if ($model->store()) {
			$msg = Text::_('COM_MAPYANDEX_SUCCESS');
		} else {
			$msg = Text::_('COM_MAPYANDEX_ERROR');
		}
		$id = $this->input->get('id', '', 'post');

		$link = 'index.php?option=com_mapyandex&controller=map&task=edit&cid[]=' . $id;
		$this->setRedirect($link, $msg);

	}
	/**
	 * remove record(s)
	 * @return void
     *
     * @since   1.6
	 */

	function remove()
	{
		$model = $this->getModel('allmaps');
        $data = $this->input->post->getArray();

		if ($model->delete($data)) {
			$msg = Text::_('COM_MAPYANDEX_SUCCESSDELETE');
		} else {
			$msg = Text::_('COM_MAPYANDEX_ERRORDELETE');
		}
		$link = 'index.php?option=com_mapyandex&view=allmaps';
		$this->setRedirect($link, $msg);

	}

	/**
	 * cancel editing a record
	 * @return void
     *
     * @since   1.6
	 */
	function cancel()
	{
		$msg = Text::_('COM_MAPYANDEX_CANCEL');
		$this->setRedirect('index.php?option=com_mapyandex&view=allmaps', $msg);
	}

    /**
     * Method to publish a list of articles.
     *
     * @return  void
     *
     * @since   1.0
     */
    public function publish()
    {

        parent::publish();

        $this->setRedirect('index.php?option=com_mapyandex&view=allmaps');
    }

    function unpublish()
    {
        $model = $this->getModel('allmaps');
        $maptable = $model->getTable('map');
        $maptable->load(1);

        $maptable->setCheckName(false);
        $maptable->setColumnAlias('published', 'published');
        $maptable->publish([], 0);

        if($maptable->check()) {
            try {
                $maptable->store();
            } catch (\Exception $e) {
                var_dump($e->getMessage());
            }
        }

        $model->setState('filter.published', 0);
        $msg = Text::_('COM_MAPYANDEX_UNPUBLISHED');
        $this->setRedirect('index.php?option=com_mapyandex&view=allmaps', $msg);
    }

}
