<?php
/*
 * @package Joomla 4.0
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Yandex Map Component
 * @copyright Copyright (C) Aleksandr Ermakov www.slyweb.ru
 */

namespace Slyweb\Component\Mapyandex\Administrator\Controller;

// No direct access
use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Controller\AdminController;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\CMS\Pagination\Pagination;
use Joomla\Input\Input;

\defined('_JEXEC') or die('Restricted access');
jimport('joomla.application.component.controllerform');

class CalculatorController extends AdminController
{
    /**
     * An array of items
     *
     * @var  array
     */
    protected $items;

    /**
     * The pagination object
     *
     * @var  Pagination
     */
    protected $pagination;

    /**
     * The model state
     *
     * @var  object
     */
    protected $state;

    /**
     * Flag if an association exists
     *
     * @var  boolean
     */
    protected $assoc;

    /**
     * Form object for search filters
     *
     * @var  \Joomla\CMS\Form\Form
     */
    public $filterForm;

    /**
     * The active search filters
     *
     * @var  array
     */
    public $activeFilters;

    /**
     * Is this view an Empty State
     *
     * @var  boolean
     * @since 4.0.0
     */
    private $isEmptyState = false;

    /**
     * Hellos view display method
     *
     * @return void
     **/

    /**
     * Constructor.
     *
     * @param   array                $config   An optional associative array of configuration settings.
     * Recognized key values include 'name', 'default_task', 'model_path', and
     * 'view_path' (this list is not meant to be comprehensive).
     * @param   MVCFactoryInterface  $factory  The factory.
     * @param   CMSApplication       $app      The Application for the dispatcher
     * @param   Input                $input    Input
     *
     * @since   3.0
     */
    public function __construct($config = array(), MVCFactoryInterface $factory = null, $app = null, $input = null)
    {
        parent::__construct($config, $factory, $app, $input);
        $this->input = \Joomla\CMS\Factory::getApplication()->input;
        // An article edit form can come from the articles or featured view.
        // Adjust the redirect view on the value of 'return' in the request.
        if ($this->input->get('return') == 'featured') {
            $this->view_list = 'featured';
            $this->view_item = 'article&return=featured';
        }
    }

    /**
     * Proxy for getModel
     *
     * @param   string  $name    The model name. Optional.
     * @param   string  $prefix  The class prefix. Optional.
     * @param   array   $config  The array of possible config values. Optional.
     *
     * @return  \Joomla\CMS\MVC\Model\BaseDatabaseModel  The model.
     *
     * @since   1.6
     */
    public function getModel($name = 'Mapyandex', $prefix = 'Administrator', $config = array('ignore_request' => true))
    {
        return parent::getModel($name, $prefix, $config);
    }

	function add()
	{
		$this->input->set('view', 'calculator');
		$this->input->set('layout', 'form');
		$this->input->set('hidemainmenu', 1);
		parent::display();
	}

	function edit()
	{
		$this->input->set('view', 'calculator');
		$this->input->set('layout', 'formedit');
		$this->input->set('hidemainmenu', 1);
		parent::display();
	}

	/**
	 * save a record (and redirect to main page)
	 * @return void
	 */
	function save()
	{
		$model = $this->getModel('calculator');
        $data = $this->input->post->getArray();
		if ($model->store($data)) {
			if(!$data['editmarket']) {
				$msg = Text::_('COM_MAPYANDEX_SUCCESSMARKET');
			} else {
				$msg = Text::_('COM_MAPYANDEX_SUCCESSMARKETEDIT');
			}

		} else {
			if(!$data['editmarket']) {
				$msg = Text::_('COM_MAPYANDEX_ERRORADDNEWMARKET');
			} else {
				$msg = Text::_('COM_MAPYANDEX_ERRORMARKETEDIT');
			}

		}
			$link = 'index.php?option=com_mapyandex&view=calculator';
			$this->setRedirect($link, $msg);
		// Check the table in so it can be edited.... we are done with it anyway

	}

	function apply()
	{
		$model = $this->getModel('calculator');
		$id = $this->input->get('id', '', 'post', 'string', JREQUEST_ALLOWRAW);
        $data = $this->input->post->getArray();

		if ($model->store($data)) {
			if(!$data['editmarket']) {
				$msg = Text::_('COM_MAPYANDEX_SUCCESSCALC');
				$link = 'index.php?option=com_mapyandex&view=calculator&layout=form&id=' . $id;
			} else {
				$msg = Text::_('COM_MAPYANDEX_SUCCESSCALC_EDIT');
				$link = 'index.php?option=com_mapyandex&view=calculator&layout=formedit&id=' . $id;
			}
		} else {
			if(!$data['editmarket']) {
				$msg = Text::_('COM_MAPYANDEX_SUCCESSCALC_EDIT_ERROR');
			} else {
				$msg = Text::_('COM_MAPYANDEX_SUCCESSCALC_EDIT_ERROR');
			}
		}
		$this->setRedirect($link, $msg);
	}

	/**
	 * remove record(s)
	 * @return void
	 */
	function remove()
	{
		$model = $this->getModel('calculator');
		if ($model->delete($post)) {
			$msg = Text::_('COM_MAPYANDEX_SUCCESSMARKET');
		} else {
			$msg = Text::_('COM_MAPYANDEX_ERRORADDNEWMARKET');
		}

		$this->setRedirect('index.php?option=com_mapyandex&view=calculator', $msg);
	}

	function deleteitem()
	{
		$model = $this->getModel('calculator');
		if ($model->deleteitem($post)) {
			$msg = Text::_('COM_MAPYANDEX_SUCCESSMARKET');
		} else {
			$msg = Text::_('COM_MAPYANDEX_ERRORADDNEWMARKET');
		}

		$this->setRedirect('index.php?option=com_mapyandex&view=calculator', $msg);
	}

	/**
	 * cancel editing a record
	 * @return void
	 */
	function cancel()
	{
		$msg = Text::_('COM_MAPYANDEX_CANCEL');
		$this->setRedirect('index.php?option=com_mapyandex&view=calculator', $msg);
	}

}
