<?php
/*
 * @package Joomla 4.x
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Yandex Map Component
 * @copyright Copyright (C) Aleksandr Ermakov www.slyweb.ru
 */

namespace Slyweb\Component\Mapyandex\Administrator\Controller;

use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Controller\AdminController;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\Input\Input;

\defined('_JEXEC') or die('Restricted access');
jimport('joomla.application.component.controllerform');

class MapController extends AdminController
{
    /**
     * Constructor.
     *
     * @param   array                $config   An optional associative array of configuration settings.
     * Recognized key values include 'name', 'default_task', 'model_path', and
     * 'view_path' (this list is not meant to be comprehensive).
     * @param   MVCFactoryInterface  $factory  The factory.
     * @param   CMSApplication       $app      The Application for the dispatcher
     * @param   Input                $input    Input
     *
     * @since   3.0
     */
    public function __construct($config = array(), MVCFactoryInterface $factory = null, $app = null, $input = null)
    {
        parent::__construct($config, $factory, $app, $input);
        $this->input = \Joomla\CMS\Factory::getApplication()->input;
        // An article edit form can come from the articles or featured view.
        // Adjust the redirect view on the value of 'return' in the request.
        if ($this->input->get('return') == 'featured') {
            $this->view_list = 'featured';
            $this->view_item = 'article&return=featured';
        }
    }
	/**
	 * display the edit form
	 * @return void
	 */
	function edit()
	{
        $this->input->set('view', 'map');
        $this->input->set('layout', 'form');
        $this->input->set('hidemainmenu', 1);

		parent::display();
	}

	function add()
	{
        $this->input->set('view', 'map');
        $this->input->set('layout', 'form');
        $this->input->set('hidemainmenu', 1);

		parent::display();
	}
	/**
	 * save a record (and redirect to main page)
	 * @return void
	 */
	function save()
	{
		$model = $this->getModel('map');
		if ($model->store()) {
			$msg = Text::_('COM_MAPYANDEX_SAVE_SUCCESS');
		} else {
			$msg = Text::_('COM_MAPYANDEX_SAVE_ERROR');
		}
		// Check the table in so it can be edited.... we are done with it anyway
		$link = 'index.php?option=com_mapyandex';
		$this->setRedirect($link, $msg);
	}

	function apply()
	{
        /** @var \Joomla\Component\Mapyandex\Administrator\Model\MapModel $model */
		$model = $this->getModel('Map', 'Administrator');

		if ($model->store()) {
			$msg = Text::_('COM_MAPYANDEX_SUCCESS');
		} else {
			$msg = Text::_('COM_MAPYANDEX_ERROR');
		}
        $input = \Joomla\CMS\Factory::getApplication()->input;
		$id = $input->getInt('id', '');

		$link = 'index.php?option=com_mapyandex&view=map&layout=form&id=' . $id;
		$this->setRedirect($link, $msg);

	}

	/**
	 * remove record(s)
	 * @return void
	 */
	function remove()
	{
		$model = $this->getModel('map');
		if ($model->delete($post)) {
			$msg = Text::_('COM_MAPYANDEX_SUCCESS');
		} else {
			$msg = Text::_('COM_MAPYANDEX_ERROR');
		}

		$this->setRedirect('index.php?option=com_mapyandex', $msg);
	}

	/**
	 * cancel editing a record
	 * @return void
	 */
	function cancel()
	{
		$msg = Text::_('COM_MAPYANDEX_CANCEL');
		$this->setRedirect('index.php?option=com_mapyandex', $msg);
	}

	function helloworld()
	{
		$msg = Text::_('COM_MAPYANDEX_CANCEL');
		$this->setRedirect('index.php?option=com_mapyandex', $msg);
	}
}
