<?php
/*
 * @package Joomla 1.5
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Yandex Map Component
 * @copyright Copyright (C) Aleksandr Ermakov www.slyweb.ru
 */

namespace Slyweb\Component\Mapyandex\Administrator\Controller;
// No direct access
use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Controller\AdminController;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\Input\Input;

defined('_JEXEC') or die('Restricted access');
jimport('joomla.application.component.controller');

class MetkiController extends AdminController
{

    /**
     * Constructor.
     *
     * @param array $config An optional associative array of configuration settings.
     * Recognized key values include 'name', 'default_task', 'model_path', and
     * 'view_path' (this list is not meant to be comprehensive).
     * @param MVCFactoryInterface $factory The factory.
     * @param CMSApplication $app The Application for the dispatcher
     * @param Input $input Input
     *
     * @since   3.0
     */

    public function __construct($config = array(), MVCFactoryInterface $factory = null, $app = null, $input = null)
    {
        parent::__construct($config, $factory, $app, $input);
        $this->input = \Joomla\CMS\Factory::getApplication()->input;
        // An article edit form can come from the articles or featured view.
        // Adjust the redirect view on the value of 'return' in the request.
        if ($this->input->get('return') == 'featured') {
            $this->view_list = 'featured';
            $this->view_item = 'article&return=featured';
        }
    }

    /**
     * Proxy for getModel
     *
     * @param string $name The model name. Optional.
     * @param string $prefix The class prefix. Optional.
     * @param array $config The array of possible config values. Optional.
     *
     * @return  \Joomla\CMS\MVC\Model\BaseDatabaseModel  The model.
     *
     * @since   1.6
     */
    public function getModel($name = 'Metka', $prefix = 'Administrator', $config = array('ignore_request' => true))
    {

        return parent::getModel($name, $prefix, $config);
    }

    function add()
    {
        $link = 'index.php?option=com_mapyandex&view=metki&layout=form';
        $this->setRedirect($link);
    }

    function edit()
    {
        $this->input->set('view', 'metki');
        $this->input->set('layout', 'formedit');
        $this->input->set('hidemainmenu', 1);
        parent::display();
    }

    /**
     * save a record (and redirect to main page)
     * @return void
     */
    function save()
    {

        $model = $this->getModel('metki');
        $data = $this->input->get('post');
        if ($model->store($data)) {
            if (!$data['editmarket']) {
                $msg = Text::_('COM_MAPYANDEX_SUCCESSMARKET');
            } else {
                $msg = Text::_('COM_MAPYANDEX_SUCCESSMARKETEDIT');
            }

        } else {
            if (!$data['editmarket']) {
                $msg = Text::_('COM_MAPYANDEX_ERRORADDNEWMARKET');
            } else {
                $msg = Text::_('COM_MAPYANDEX_ERRORMARKETEDIT');
            }

        }
        $link = 'index.php?option=com_mapyandex&view=metki';
        $this->setRedirect($link, $msg);
        // Check the table in so it can be edited.... we are done with it anyway

    }

    function apply()
    {
        $model = $this->getModel('metki');

        $data = $this->input->get('post');
        if ($model->store($post)) {
            if (!$data['editmarket']) {
                $msg = Text::_('COM_MAPYANDEX_SUCCESSMARKET');
            } else {
                $msg = Text::_('COM_MAPYANDEX_SUCCESSMARKETEDIT');
            }

        } else {
            if (!$data['editmarket']) {
                $msg = Text::_('COM_MAPYANDEX_ERRORADDNEWMARKET');
            } else {
                $msg = Text::_('COM_MAPYANDEX_ERRORMARKETEDIT');
            }

        }
        $id = $this->input->get('id', '', 'post', 'string', JREQUEST_ALLOWRAW);

        $link = 'index.php?option=com_mapyandex&view=metki&layout=formedit&id=' . $id;
        $this->setRedirect($link, $msg);
    }

    /**
     * remove record(s)
     * @return void
     */
    function remove()
    {
        $post = $this->input->get('post');
        $model = $this->getModel('metki');
        if ($model->delete($post)) {
            $msg = Text::_('COM_MAPYANDEX_SUCCESSMARKET');
        } else {
            $msg = Text::_('COM_MAPYANDEX_ERRORADDNEWMARKET');
        }
        $this->setRedirect('index.php?option=com_mapyandex&view=metki', $msg);
    }

    /**
     * cancel editing a record
     * @return void
     */
    function cancel()
    {
        $msg = Text::_('COM_MAPYANDEX_CANCEL');
        $this->setRedirect('index.php?option=com_mapyandex&view=metki', $msg);
    }

    /**
     * Method to publish a list of articles.
     *
     * @return  void
     *
     * @since   1.0
     */
    public function publish()
    {

        parent::publish();
        $this->setRedirect('index.php?option=com_mapyandex&view=metki');
    }

    function unpublish()
    {
        $model = $this->getModel('allmaps');
        $maptable = $model->getTable('metki');
        $maptable->load(1);

        $maptable->setCheckName(false);
        $maptable->setColumnAlias('published', 'published');
        $maptable->publish([], 0);

        if($maptable->check()) {
            try {
                $maptable->store();
            } catch (\Exception $e) {
                var_dump($e->getMessage());
            }
        }

        $model->setState('filter.published', 0);
        $msg = Text::_('COM_MAPYANDEX_UNPUBLISHED');
        $this->setRedirect('index.php?option=com_mapyandex&view=allmaps', $msg);
    }
}
