<?php
/*
 * @package Joomla 1.5
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Yandex Map Component
 * @copyright Copyright (C) Aleksandr Ermakov www.slyweb.ru
 */

namespace Slyweb\Component\Mapyandex\Administrator\Controller;

// No direct access
use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Controller\AdminController;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\Input\Input;

\defined('_JEXEC') or die('Restricted access');

class RouteController extends AdminController
{
    /**
     * Constructor.
     *
     * @param   array                $config   An optional associative array of configuration settings.
     * Recognized key values include 'name', 'default_task', 'model_path', and
     * 'view_path' (this list is not meant to be comprehensive).
     * @param   MVCFactoryInterface  $factory  The factory.
     * @param   CMSApplication       $app      The Application for the dispatcher
     * @param   Input                $input    Input
     *
     * @since   3.0
     */

    public function __construct($config = array(), MVCFactoryInterface $factory = null, $app = null, $input = null)
    {
        parent::__construct($config, $factory, $app, $input);
        $this->input = \Joomla\CMS\Factory::getApplication()->input;
        // An article edit form can come from the articles or featured view.
        // Adjust the redirect view on the value of 'return' in the request.
        if ($this->input->get('return') == 'featured') {
            $this->view_list = 'featured';
            $this->view_item = 'article&return=featured';
        }
    }

	function add()
	{
        $this->input->set('view', 'route');
        $this->input->set('layout', 'form');
        $this->input->set('hidemainmenu', 1);
		parent::display();
	}

	function edit()
	{
        $this->input->set('view', 'route');
        $this->input->set('layout', 'formedit');
        $this->input->set('hidemainmenu', 1);
		parent::display();
	}

	/**
	 * save a record (and redirect to main page)
	 * @return void
	 */
	function save()
	{

		$model = $this->getModel('route');
        $data = $this->input->get('post');
		if ($model->store($data)) {
			if(!$data['editmarket']) {
				$msg = Text::_('COM_MAPYANDEX_SUCCESSMARKET');
			} else {
				$msg = Text::_('COM_MAPYANDEX_SUCCESSMARKETEDIT');
			}

		} else {
			if(!$data['editmarket']) {
				$msg = Text::_('COM_MAPYANDEX_ERRORADDNEWMARKET');
			} else {
				$msg = Text::_('COM_MAPYANDEX_ERRORMARKETEDIT');
			}

		}
			$link = 'index.php?option=com_mapyandex&view=route';
			$this->setRedirect($link, $msg);
		// Check the table in so it can be edited.... we are done with it anyway

	}

	function apply()
	{
		$model = $this->getModel('route');

		$data = $this->input->post->getArray();

		if ($model->store($data)) {
			if(!$data['editmarket']) {
				$msg = Text::_('COM_MAPYANDEX_SUCCESSROUTE');
			} else {
				$msg = Text::_('COM_MAPYANDEX_SUCCESSROUTE_EDIT');
			}

		} else {
			if(!$data['editmarket']) {
				$msg = Text::_('COM_MAPYANDEX_SUCCESSROUTE_ERRORADDNEW');
			} else {
				$msg = Text::_('COM_MAPYANDEX_ERROR_EDIT');
			}

		}
		$id = $this->input->get('id', '', 'post', 'string', JREQUEST_ALLOWRAW);

		$link = 'index.php?option=com_mapyandex&view=route&layout=form&id=' . $id;
		$this->setRedirect($link, $msg);

	}
	/**
	 * remove record(s)
	 * @return void
	 */
	function remove()
	{
		$model = $this->getModel('route');
		if ($model->delete($post)) {
			$msg = Text::_('COM_MAPYANDEX_SUCCESSMARKET');
		} else {
			$msg = Text::_('COM_MAPYANDEX_ERRORADDNEWMARKET');
		}

		$this->setRedirect('index.php?option=com_mapyandex&view=route', $msg);
	}

	function deleteitem()
	{
		$model = $this->getModel('route');
		if ($model->deleteitem($post)) {
			$msg = Text::_('COM_MAPYANDEX_SUCCESSMARKET');
		} else {
			$msg = Text::_('COM_MAPYANDEX_ERRORADDNEWMARKET');
		}

		$this->setRedirect('index.php?option=com_mapyandex&view=route', $msg);
	}

	/**
	 * cancel editing a record
	 * @return void
	 */
	function cancel()
	{
		$msg = Text::_('COM_MAPYANDEX_CANCEL');
		$this->setRedirect('index.php?option=com_mapyandex&view=route', $msg);
	}

}
