<?php
/*
 * @package Joomla 1.5
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Yandex Map Component
 * @copyright Copyright (C) Aleksandr Ermakov www.slyweb.ru
 */

namespace Slyweb\Component\Mapyandex\Administrator\Model;

// No direct access
use JFactory;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Associations;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\CMS\MVC\Model\ListModel;
use Joomla\Registry\Registry;
use JPagination;
use JTable;
use stdClass;

\defined('_JEXEC') or die('Restricted access');
jimport('joomla.application.component.modeladmin');
jimport('joomla.html.pagination');
jimport('joomla.application.component.modellist');

class AllmapsModel extends ListModel
{
    protected $option = 'com_mapyandex';
    /**
     * @var JPagination
     */
    private $pageNav;
    /**
     * @var \Joomla\Input\Input
     */
    private $input;

    /**
     * Constructor.
     *
     * @param array $config An optional associative array of configuration settings.
     * @param MVCFactoryInterface|null $factory The factory.
     *
     * @since   1.6
     */
    public function __construct($config = array(), MVCFactoryInterface $factory = null)
    {
        $this->input = Factory::getApplication()->input;

        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'id', 'a.id',
                'name', 'a.name_map_yandex',
                'hits', 'a.hits',
                'published', 'a.published',
            );
        }
        if (Associations::isEnabled()) {
            $config['filter_fields'][] = 'association';
        }

        parent::__construct($config, $factory);
    }
    public function test($type = 'Map', $prefix = 'Table', $config = array())
    {
        var_dump(123);
    }

    public function getTable($type = 'Map', $prefix = 'Table', $config = array())
    {
        return JTable::getInstance($type, $prefix, $config);
    }

    protected function getListQuery()
    {
        $db = $this->getDatabase();
        $query = $db->getQuery(true);
        $user = Factory::getUser();
        $params = ComponentHelper::getParams('com_mapyandex');
        //CHANGE THIS QUERY AS YOU NEED...
        $query->select(
        	$this->getState(
        		'list.select',
        		[
                    $db->quoteName('a.id'),
                    $db->quoteName('a.name_map_yandex'),
                    $db->quoteName('a.catid'),
                    $db->quoteName('a.published'),
                    $db->quoteName('a.ordering'),
                    $db->quoteName('a.hits'),
                    $db->quoteName('a.misil'),
                    $db->quoteName('a.map_type'),
                    $db->quoteName('a.checked_out_time'),
                    $db->quoteName('a.misilonclick'),

                ]
        	)
        )
            ->select(
            	[
                    $db->quoteName('a.id'),
                    $db->quoteName('a.name_map_yandex'),
                    $db->quoteName('a.catid'),
                    $db->quoteName('a.published'),
                    $db->quoteName('a.ordering'),
                    $db->quoteName('a.hits'),
                    $db->quoteName('a.misil'),
                    $db->quoteName('a.map_type'),
                    $db->quoteName('a.checked_out_time'),
                    $db->quoteName('a.misilonclick'),
                ]
            )
            ->from($db->quoteName('#__map_yandex', 'a'));
        // Filter by search in title.
        $search = $this->getState('filter.search');

        if (!empty($search)) {
            $search = '%' . str_replace(' ', '%', trim($search)) . '%';

            $query->where(
            	'(' . $db->quoteName('a.name_map_yandex') . ' LIKE :search1 OR ' . $db->quoteName('a.misil') . ' LIKE :search2' . ' OR ' . $db->quoteName('a.misilonclick') . ' LIKE :search3)'
            )
                ->bind([':search1', ':search2', ':search3'], $search);
        }
        $published = $this->getState('filter.published');

        if($published !== "" and $published !== null) {
            $query->where('(' . $db->quoteName('a.published') . ' = :published )')->bind([':published'], $published);
        }
        // Add the list ordering clause.
        $orderCol = $this->state->get('list.ordering', 'a.id');
        $orderDirn = $this->state->get('list.direction', 'DESC');

        if ($orderCol === 'a.name_map_yandex' || $orderCol === 'catid') {
            $ordering = [
                $db->quoteName('a.name_map_yandex') . ' ' . $db->escape($orderDirn),
                $db->quoteName('a.ordering') . ' ' . $db->escape($orderDirn),
            ];
        } else {
            $ordering = $db->escape($orderCol) . ' ' . $db->escape($orderDirn);
        }
        $query->order($ordering);
        return $query;
    }

    /**
     * Method to auto-populate the model state.
     *
     * Note. Calling getState in this method will result in recursion.
     *
     * @since    1.6
     */
    protected function populateState($ordering = null, $direction = null)
    {
        // Initialise variables.
        $app = JFactory::getApplication('administrator');

        $published = $this->getUserStateFromRequest($this->context . '.filter.published', 'filter_published', '');
        $this->setState('filter.published', $published);

        // Load the filter state.
        $search = $app->getUserStateFromRequest('filter.search', 'filter_search');
        $this->setState('filter.search', $search);

        $published = $this->getUserStateFromRequest($this->context . '.filter.id', 'fullordering', '');
        $this->setState('filter.fullordering', $published);
        // List state information.

        parent::populateState($ordering, $direction);
    }

    /**
     * Get the filter form
     *
     * @param array $data data
     * @param boolean $loadData load current data
     *
     * @return  \Joomla\CMS\Form\Form|null  The Form object or null if the form can't be found
     *
     * @since   3.2
     */
    public function getFilterForm($data = array(), $loadData = true)
    {
        $form = parent::getFilterForm($data, $loadData);
        $params = ComponentHelper::getParams('com_mapyandex');

        if (!$params->get('workflow_enabled')) {

            $form->removeField('stage', 'filter');
        } else {
            $ordering = $form->getField('fullordering', 'list');
            $ordering->addOption('JSTAGE_ASC', ['value' => 'ws.title ASC']);
            $ordering->addOption('JSTAGE_DESC', ['value' => 'ws.title DESC']);
        }

        return $form;
    }

    public function getForm($data = array(), $loadData = true)
    {

        $form = $this->loadForm('com_mapyandex.mapyandexallmaps', 'map', array('control' => 'jform', 'load_data' => $loadData));
        if (empty($form)) {
            return false;
        }

        return $form;
    }

    /**
     * @возвращает список строк в файл view.html.php
     *
     * @since 2.5
     */
    function getDefaultSettings()
    {
        $s = new stdClass();
        $s->yandexcoord = '';
        $s->city_map_yandex = '';
        $s->yandexbutton = 1;
        $s->yandexzoom = 14;
        $s->city_map_yandex = '';
        $s->street_map_yandex = '';
        $s->defaultmap = '';
        $s->width_map_yandex = 500;
        $s->height_map_yandex = 500;
        $s->misilonclick = '';
        $s->yandexborder = 0;
        $s->bradius = 0;
        $s->center_map_yandex = '';
        $s->autozoom = 0;
        $s->color_map_yandex = '';
        $s->oblako_width_map_yandex = '';
        $s->name_map_yandex = '';

        return $s;
    }

    /**
     * @return array строк в файл view.html.php
     *
     * @throws \Exception
     * @since 2.5
     */

    function getAllMaps()
    {

        // Create a new query object.
        $db = $this->getDatabase();
        $query = $db->getQuery(true);
        //вставляем насройки последней карты в новую...
        $input = Factory::getApplication()->input;
        $data['task'] = $input->get('task');
        $data['layout'] = $input->get('layout');
        if ($data['task'] !== 'add') {
            $app = JFactory::getApplication();
            $limit = $input->get('limit', $app->getCfg('list_limit'));

            $limitstart = $input->get('limitstart', 0);

            $query->select('a.*');
            $query->from('`#__map_yandex` AS a');
            $search = $this->getState('filter.search');

            if (!empty($search)) {
                if (stripos($search, 'id:') === 0) {
                    $query->where('a.id = ' . (int) substr($search, 3));

                } else {

                    $search = $db->Quote('%' . $db->escape($search, true) . '%');

                    $query->where('( a.name_map_yandex LIKE ' . $search . ')');
                }
            }
            $query->order('ID DESC');
            if ($data['layout'] == 'form') $limit = 1;
            $query = $db->setQuery($query, $limitstart, $limit);
            $this->_foobar = $db->loadObjectList();

        } else {

            $query = ' SELECT * '
                . ' FROM #__map_yandex ORDER BY ID DESC';
            $query = $db->setQuery($query);
            $this->_foobar = $db->loadObject();
        }

        return $this->_foobar;
    }

    /**
     * @возвращает список строк в файл view.html.php
     */

    /**
     * Method to get a list of articles.
     * Overridden to add item type alias.
     *
     * @return  mixed  An array of data items on success, false on failure.
     *
     * @since   4.0.0
     */
    public function getItems()
    {
        $items = parent::getItems();
        foreach ($items as $item) {
            $item->typeAlias = 'com_mapyandex.map';
            if (isset($item->metadata)) {
                $registry = new Registry($item->metadata);
                $item->metadata = $registry->toArray();
            }
        }

        return $items;
    }

    /**
     * Вывод мудрых мыслей с пагинацией
     * @возвращает список строк в файл view.html.php
     */

    function getReviews()
    {
        $app = JFactory::getApplication();
        $limit = $this->input->getInt('limit', $app->getCfg('list_limit'));

        $limitstart = $this->input->getInt('limitstart', 0);

        $db = Factory::getContainer()->get('DatabaseDriver');
        $query = "SELECT count(*) FROM #__map_yandex";
        $db->setQuery($query);
        $total = $db->loadResult();
        $query = "SELECT * FROM #__map_yandex";
        $db->setQuery($query, $limitstart, $limit);
        $rows = $db->loadObjectList();
        if (!$db->execute()) {
            echo $db->stderr();

            return false;
        }

        return $this->pageNav = new JPagination($total, $limitstart, $limit);

    }

    function getDefault()
    {
        $def = new stdClass();
        $def->id_map_yandex = '';
        $def->yandexcoord = '';
        $def->city_map_yandex = '';
        $def->street_map_yandex = '';
        $def->misilonclick = '';
        $def->yandexbutton = '';
        $def->autozoom = true;
        $def->yandexzoom = 10;
        $def->yandexbutton = 1;
        $def->defaultmap = '';
        $def->width_map_yandex = 500;
        $def->height_map_yandex = 500;
        $def->yandexborder = 0;
        $def->bradius = 0;
        $def->center_map_yandex = 0;

        return $def;
    }

    function textnl($text)
    {
        $text = str_replace("\r\n", "<br />", $text);
        $text = str_replace("\r", "<br />", $text);
        $text = str_replace("\n\n", '<p>', $text);
        $text = str_replace("\n", '<br />', $text);
        $text = addslashes($text);

        return $text;
    }

    function store()
    {
        $row = $this->getTable('map');
        $jinput = JFactory::getApplication()->input->post;
        $data = $jinput->getArray();

        $data['misil'] = $jinput->get('misil', '', 'str');
        $data['misilonclick'] = $jinput->get('misilonclick', '', 'str');
        $data['text_map_yandex'] = $jinput->get('jform', '', 'str');
        $jform = $data['jform'];
        // Bind the form fields to the hello table
        if (!$row->bind($data)) {
            $this->setError($this->_db->getErrorMsg());

            return false;
        }

        // Make sure the hello record is valid

        (trim($data['width_map_yandex']) !== '') ? $data['width_map_yandex'] = $data['width_map_yandex'] : $data['width_map_yandex'] = 500;
        (trim($data['height_map_yandex']) !== '') ? $data['height_map_yandex'] = $data['height_map_yandex'] : $data['height_map_yandex'] = 500;
        $date = date("Y-m-d H:i:s", time());
        $lng = json_encode(array('longitude_map_yandex' => $data['longitude_map_yandex'], 'latitude_map_yandex' => $data['latitude_map_yandex']));
        $el = json_encode($data['yandexel']);
        // Store the web link table to the database
        $db = $this->getDatabase();
        $query = "INSERT INTO " . $db->quoteName('#__map_yandex')
            . " (`misil`,`misilonclick`,`name_map_yandex`,`defaultmap`, `id_map_yandex`, `city_map_yandex`, `street_map_yandex`, `checked_out`, `ordering`, `published`, `hits`, `catid`, `params`, `width_map_yandex`, `height_map_yandex`, `oblako_width_map_yandex`, `yandexbutton`, `color_map_yandex`, `bradius`, `yandexborder`,`yandexcoord`,`lng`,`yandexzoom`,`yandexel`,`text_map_yandex`,`checked_out_time`,`route_map_yandex`,`region_map_yandex`) VALUES
			('" . $this->textnl($data['misil']) . "','" . $this->textnl($data['misilonclick']) . "','" . $data['name_map_yandex'] . "','" . $data['defaultmap'] . "','" . $data['id_map_yandex'] . "', '" . $data['city_map_yandex'] . "', '" . $data['street_map_yandex'] . "', 0, 4, 1, 0, 1, '', '" . $data['width_map_yandex'] . "', '" . $data['height_map_yandex'] . "', '" . $data['oblako_width_map_yandex'] . "', '" . $data['yandexbutton'] . "', '" . $jform['color_map_yandex'] . "', '" . $data['bradius'] . "', '" . $data['yandexzoom'] . "','" . $data['yandexcoord'] . "','$lng','" . $data['yandexzoom'] . "','" . $el . "','" . $this->textnl($jform['text_map_yandex']) . "','" . $date . "','','')";
        $db->setQuery($query);

        if (!$db->execute()) {
            Factory::getApplication()->enqueueMessage($db->getError(), 'error');
            return false;
        }

        return true;
    }

    function delete(&$post)
    {
        $cids = $post['cid'];
        $db = $this->getDatabase();
        if (\count($cids)) {
            foreach ($cids as $cid) {
                $query = 'DELETE FROM #__map_yandex' . ' WHERE id = ' . $cid;
                $db->setQuery($query);
                if (!$db->execute()) {
                    Factory::getApplication()->enqueueMessage($db->getError(), 'error');

                    return false;
                }
            }
        }

        return true;
    }

}
