<?php
/*
 * @package Joomla 4.0
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Yandex Map Component
 * @copyright Copyright (C) Aleksandr Ermakov www.slyweb.ru
 */

namespace Slyweb\Component\Mapyandex\Administrator\Model;

// No direct access
use JFactory;
use Joomla\CMS\Factory;
use Joomla\CMS\MVC\Model\AdminModel;

use JTable;

\defined('_JEXEC') or die('Restricted access');
jimport('joomla.application.component.modeladmin');
jimport('joomla.html.pagination');
jimport('joomla.application.component.modellist');

class MapModel extends AdminModel
{
    /**
     * Foobar ID
     *
     * @var int
     * @since    2.5
     */
    var $_id;

    /**
     * Foobar data
     *
     * @var object
     * @since    2.5
     */

    var $_foobar;
    var $_metka;
    var $map;
    /**
     * @var mixed
     * @since    2.5
     */
    private $db;

    /**
     * Constructor, builds object and determines the foobar ID
     * @since    2.5
     */
    function __construct()
    {
        parent::__construct();
        // get the cid array from the default request hash
        $this->input = Factory::getApplication()->input;
        $id = $this->input->get('id');
        $this->setId($id);
        $this->db  = Factory::getContainer()->get('DatabaseDriver');
    }

    /**
     * Returns a reference to the a Table object, always creating it.
     *
     * @param type    The table type to instantiate
     * @param string    A prefix for the table class name. Optional.
     * @param array    Configuration array for model. Optional.
     * @return    JTable    A database object
     * @since    2.5
     */
    public function getTable($type = 'Map', $prefix = 'Table', $config = array()): JTable
    {
        return JTable::getInstance($type, $prefix, $config);
    }

    /**
     * Method to get the record form.
     *
     * @param array $data Data for the form.
     * @param boolean $loadData True if the form is to load its own data (default case), false if not.
     * @return    mixed    A JForm object on success, false on failure
     * @since    2.5
     */
    public function getForm($data = array(), $loadData = true)
    {
        // Get the form.
        $form = $this->loadForm('com_mapyandex.map', 'map', array('control' => 'jform', 'load_data' => $loadData));
        if (empty($form)) {
            return false;
        }

        return $form;
    }

    /**
     * Method to get the script that have to be included on the form
     *
     * @return string    Script files
     * @since    2.5
     */
    public function getScript()
    {
        return 'administrator/components/com_mapyandex/models/forms/map.js';
    }

    /**
     * Method to get the data that should be injected in the form.
     *
     * @return    mixed    The data for the form.
     * @since    2.5
     */
    protected function loadFormData()
    {
        // Check the session for previously entered form data.
        $data = JFactory::getApplication()->getUserState('com_mapyandex.edit.map.data', array());
        if (empty($data)) {
            $data = $this->getItem();
        }

        return $data;
    }

    function setId($id)
    {
        $this->_id = $id;
        $this->_foobar = null;
    }

    function getFoobar()
    {
        if (!$this->_foobar) {
            $db = $this->getDatabase();
            $query = "SELECT * FROM " . $db->quoteName('#__map_yandex') . " WHERE " . $db->quoteName('id') . " = " . $this->_id;

            $db->setQuery($query);
            $this->_foobar = $db->loadObject();
        }
        // return the foobar data
        return $this->_foobar;

    }

    function getMetka()
    {
        $query = "SELECT * FROM " . $this->db->quoteName('#__map_yandex_metki') . " WHERE " . $this->db->quoteName('id_map') . " = " . $this->_id;
        $this->db->setQuery($query);
        $this->_metka =  $this->db->loadObjectList();
        // return the foobar data
        return $this->_metka;

    }

    function textnl($text)
    {
        $text = str_replace("\r\n", "<br />", $text);
        $text = str_replace("\r", "<br />", $text);
        $text = str_replace("\n\n", '<p>', $text);
        $text = str_replace("\n", '<br />', $text);
        $text = addslashes($text);

        return $text;
    }

    /**
     * Method to store a record
     *
     * @access    public
     * @return    boolean    True on success
     * @throws \Exception
     * @throws \Exception
     * @since    2.5
     */
    function store()
    {
        $row = $this->getTable();
        $jinput = JFactory::getApplication()->input->post;

        $data = $jinput->getArray();
        $data['misil'] = $jinput->get('misil', '', 'str');
        $data['misilonclick'] = $jinput->get('misilonclick', '', 'str');
        $form = $jinput->get('jform', '', 'RAW');

        // Bind the form fields to the hello table
        if (!$row->bind($data)) {
            Factory::getApplication()->enqueueMessage($this->db->getError(), 'error');

            return false;
        }

        $lng = json_encode(array('longitude_map_yandex' => $data['longitude_map_yandex'], 'latitude_map_yandex' => $data['latitude_map_yandex']));
        $el = json_encode($data['yandexel']);
        $date = date("Y-m-d H:i:s", time());
        // Store the web link table to the database
        $db =  $this->db;
        if (empty($data['oblako_width_map_yandex'])) {
            $data['oblako_width_map_yandex'] = 0;
        }
        //dd($data);
        $query = "UPDATE " . $db->quoteName('#__map_yandex')
            . " set " . $db->quoteName('misil') . " = '" . $this->textnl($data['misil'])
            . "', " . $db->quoteName('misilonclick') . " = '" . $this->textnl($data['misilonclick'])
            . "', " . $db->quoteName('id_map_yandex') . " = '" . $data['id']
            . "', " . $db->quoteName('checked_out_time') . " = '" . $date
            . "', " . $db->quoteName('defaultmap') . " = '" . $data['defaultmap']
            . "', " . $db->quoteName('name_map_yandex') . " = '" . $data['name_map_yandex']
            . "', " . $db->quoteName('city_map_yandex') . " = '" . $data['city_map_yandex']
            . "', " . $db->quoteName('street_map_yandex') . " = '" . $data['street_map_yandex']
            . "', " . $db->quoteName('width_map_yandex') . " = '" . $data['width_map_yandex']
            . "', " . $db->quoteName('height_map_yandex') . " = '" . $data['height_map_yandex']
            . "', " . $db->quoteName('oblako_width_map_yandex') . " = '" . $data['oblako_width_map_yandex']
            . "', " . $db->quoteName('yandexbutton') . " = '" . $data['yandexbutton']
            . "', " . $db->quoteName('color_map_yandex') . " = '" . $form['color_map_yandex']
            . "', " . $db->quoteName('bradius') . " = '" . $data['bradius']
            . "', " . $db->quoteName('center_map_yandex') . " = '" . $data['center_map_yandex']
            . "', " . $db->quoteName('yandexborder') . " = '" . $data['yandexborder']
            . "', " . $db->quoteName('text_map_yandex') . " = '" . $db->escape($form['text_map_yandex'])
            . "', " . $db->quoteName('where_text') . " = '" . $data['where_text']
            . "', " . $db->quoteName('yandexcoord') . " = '" . $data['yandexcoord']
            . "', " . $db->quoteName('lng') . " = '" . $lng
            . "', " . $db->quoteName('yandexzoom') . " = '" . $data['yandexzoom']
            . "', " . $db->quoteName('autozoom') . " = '" . $form['autozoom']
            . "', " . $db->quoteName('yandexel') . " = '" . $el
            . "', " . $db->quoteName('map_baloon_or_placemark') . " = '" . $form['map_baloon_or_placemark']
            . "', " . $db->quoteName('map_baloon_minwidth') . " = '" . $form['map_baloon_minwidth']
            . "', " . $db->quoteName('map_baloon_minheight') . " = '" . $form['map_baloon_minheight']
            . "', " . $db->quoteName('map_baloon_autopanduration') . " = '" . $form['map_baloon_autopanduration']
            . "', " . $db->quoteName('map_baloon_autopan') . " = '" . $form['map_baloon_autopan']
            . "', " . $db->quoteName('map_centering') . " = '" . $form['map_centering']
            . "', " . $db->quoteName('map_settings_user_all') . " = '" . $form['map_settings_user_all']
            . "' WHERE " . $db->quoteName('id') . " =" . $data['id'];

        $db->setQuery($query);
        if (!$db->execute()) {
            Factory::getApplication()->enqueueMessage($db->getError(), 'error');

            return false;
        }

        return true;
    }

    /**
     * Method to delete record(s)
     *
     * @access    public
     * @return    boolean    True on success
     *
     * TODO удалять регионы
     * @throws \Exception
     * @since    4.0
     */
    public function deleteregion(&$post)
    {
        $cids = $this->input->get('cid', array(0), 'post', 'array');

        $table = $this->getTable();

        foreach ($cids as $id) {
            if(!$row = $table->load(array('id'=>$id)))
            {
                Factory::getApplication()->enqueueMessage($row->getError(), 'error');
            }

            $table->set('region_map_yandex', '');
            if ($table->check())
            {
                if (!$table->store())
                {
                    // обработчик ошибок записи
                    Factory::getApplication()->enqueueMessage($table->getError(), 'error');
                }
            } else {
                // обработчик ошибки проверки буфера
                // тоже используем $table->getError()
                Factory::getApplication()->enqueueMessage($table->getError(), 'error');
            }
        }

        return true;
    }

    function hit()
    {
        $db = $this->db;
        $db->setQuery('UPDATE ' . $db->quoteName('#__map_yandex')
            . 'SET ' . $db->quoteName('hits') . ' = ' . $db->quoteName('hits') . ' + 1 ' . 'WHERE id = ' . $this->_id);
        $db->query();
    }

}
