<?php
/*
 * @package Joomla 1.5
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Yandex Map Component
 * @copyright Copyright (C) Aleksandr Ermakov www.slyweb.ru
 */

namespace Slyweb\Component\Mapyandex\Administrator\Model;

// No direct access
use JFactory;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Associations;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\CMS\MVC\Model\ListModel;
use Joomla\Registry\Registry;
use JPagination;
use JTable;
use stdClass;

\defined('_JEXEC') or die('Restricted access');
jimport('joomla.application.component.modeladmin');
jimport('joomla.html.pagination');
jimport('joomla.application.component.modellist');

class MetkiModel extends ListModel
{
    var $_foobar;
    var $_editmarker;
    protected $option = 'com_mapyandex';
    /**
     * Constructor.
     *
     * @param array $config An optional associative array of configuration settings.
     * @param MVCFactoryInterface|null $factory The factory.
     *
     * @since   1.6
     */
    public function __construct($config = array(), MVCFactoryInterface $factory = null)
    {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'id', 'a.id',
                'name', 'a.name_marker',
                'published', 'a.published',
            );
        }
        if (Associations::isEnabled()) {
            $config['filter_fields'][] = 'association';
        }
        // get the cid array from the default request hash
        $this->input = JFactory::getApplication()->input;
        $id = $this->input->getInt('id', 1);
        $this->setId($id);
        parent::__construct($config, $factory);
    }

    public function getTable($type = 'Metki', $prefix = 'Table', $config = array())
    {
        return JTable::getInstance($type, $prefix, $config);
    }

    /**
     * Method to auto-populate the model state.
     *
     * Note. Calling getState in this method will result in recursion.
     *
     * @since    1.6
     */
    protected function populateState($ordering = null, $direction = null)
    {
        // Initialise variables.
        $app = JFactory::getApplication('administrator');

        $published = $this->getUserStateFromRequest($this->context . '.filter.published', 'filter_published', '');
        $this->setState('filter.published', $published);

        // Load the filter state.
        $search = $app->getUserStateFromRequest('filter.search', 'filter_search');
        $this->setState('filter.search', $search);

        $published = $this->getUserStateFromRequest($this->context . '.filter.id', 'fullordering', '');
        $this->setState('filter.fullordering', $published);
        // List state information.

        parent::populateState($ordering, $direction);
    }


    /**
     * Get the filter form
     *
     * @param array $data data
     * @param boolean $loadData load current data
     *
     * @return  \Joomla\CMS\Form\Form|null  The Form object or null if the form can't be found
     *
     * @since   3.2
     */
    public function getFilterForm($data = array(), $loadData = true)
    {
        $form = parent::getFilterForm($data, $loadData);
        $params = ComponentHelper::getParams('com_mapyandex');
        if (!$params->get('workflow_enabled')) {
            $form->removeField('stage', 'filter');
        } else {
            $ordering = $form->getField('fullordering', 'list');
            $ordering->addOption('JSTAGE_ASC', ['value' => 'ws.title ASC']);
            $ordering->addOption('JSTAGE_DESC', ['value' => 'ws.title DESC']);
        }
        return $form;
    }

    public function getForm($data = array(), $loadData = true)
    {

        $form = $this->loadForm('com_mapyandex.mapyandexallmaps', 'map', array('control' => 'jform', 'load_data' => $loadData));
        if (empty($form)) {
            return false;
        }

        return $form;
    }


    function setId($id)
    {
        $this->_id = $id;
        $this->_foobar = null;
    }

    function getEditmarker()
    {
        $db = $this->getDatabase();
        $query = ' SELECT * FROM #__map_yandex_metki WHERE id=' . $this->_id;
        $query = $db->setQuery($query);
        $this->_editmarker = $db->loadObjectList();
        return $this->_editmarker;
    }

    public function getItems()
    {
        $items = parent::getItems();

        foreach ($items as $item) {
            $item->typeAlias = 'com_mapyandex.metki';
            if (isset($item->metadata)) {
                $registry = new Registry($item->metadata);
                $item->metadata = $registry->toArray();
            }
        }

        return $items;
    }

    protected function getListQuery()
    {
        $db = $this->getDatabase();
        $query = $db->getQuery(true);

        $query->select(
        	$this->getState(
        		'list.select',
        		[
                    $db->quoteName('a.id'),
                    $db->quoteName('a.name_marker'),
                    $db->quoteName('a.misil'),
                    $db->quoteName('a.misilonclick'),
                    $db->quoteName('a.whoadd'),
                    $db->quoteName('a.userimg'),
                    $db->quoteName('a.published'),
                    $db->quoteName('a.ordering'),
                    $db->quoteName('a.hits'),
                    $db->quoteName('a.id_map'),
                    $db->quoteName('a.deficon'),
                    $db->quoteName('a.checked_out_time'),
                    $db->quoteName('username'),

                ]
        	)
        )
            ->select(
            	[
                    $db->quoteName('a.id'),
                    $db->quoteName('a.name_marker'),
                    $db->quoteName('a.misil'),
                    $db->quoteName('a.misilonclick'),
                    $db->quoteName('a.whoadd'),
                    $db->quoteName('a.userimg'),
                    $db->quoteName('a.published'),
                    $db->quoteName('a.ordering'),
                    $db->quoteName('a.hits'),
                    $db->quoteName('a.id_map'),
                    $db->quoteName('a.deficon'),
                    $db->quoteName('a.checked_out_time'),
                    $db->quoteName('username'),
                ]
            )
            ->from($db->quoteName('#__map_yandex_metki', 'a'))
            ->leftJoin('#__users ON a.whoadd = #__users.id');
        // Filter by search in title.
        $search = $this->getState('filter.search');

        $published = $this->getState('filter.published');

        if (!empty($search)) {
            $search = '%' . str_replace(' ', '%', trim($search)) . '%';

            $query->where(
            	'(' . $db->quoteName('a.name_marker') . ' LIKE :search1 OR ' . $db->quoteName('a.misil') . ' LIKE :search2' . ' OR ' . $db->quoteName('a.misilonclick') . ' LIKE :search3)'
            )
                ->bind([':search1', ':search2', ':search3'], $search);
        }

        // Add the list ordering clause.
        $orderCol = $this->state->get('list.ordering', 'a.id');
        $orderDirn = $this->state->get('list.direction', 'DESC');

        if($published !== "" and $published !== null) {
            $query->where('(' . $db->quoteName('a.published') . ' = :published )')->bind([':published'], $published);
        }
        if ($orderCol === 'a.name_marker' || $orderCol === 'catid') {
            $ordering = [
                $db->quoteName('a.name_marker') . ' ' . $db->escape($orderDirn),
                $db->quoteName('a.ordering') . ' ' . $db->escape($orderDirn),
            ];
        } else {
            $ordering = $db->escape($orderCol) . ' ' . $db->escape($orderDirn);
        }

        $query->order($ordering);
        //dump($query->__toString());
        return $query;
    }

    /**
     * Вывод мудрых мыслей с пагинацией
     * @возвращает список строк в файл view.html.php
     */

    function getReviews()
    {
        global $option, $mainframe;
        $app = JFactory::getApplication();
        $limit = $this->input->getInt('limit', $app->getCfg('list_limit'));

        $limitstart = $this->input->getInt('limitstart', 0);
        $db = $this->getDatabase();
        $query = "SELECT count(*) FROM #__map_yandex_metki";
        $db->setQuery($query);
        $total = $db->loadResult();

        $query = "SELECT * FROM #__map_yandex_metki";
        $db->setQuery($query, $limitstart, $limit);
        $rows = $db->loadObjectList();
        try  {
            $db->execute();
        } catch(Exception $e) {
            Factory::getApplication()->enqueueMessage($e->getMessage(),'error');
            return false;
        }

        return $this->pageNav = new JPagination($total, $limitstart, $limit);
    }

    function textnl($text)
    {
        $text = str_replace("\r\n", "<br />", $text);
        $text = str_replace("\r", "<br />", $text);
        $text = str_replace("\n\n", '<p>', $text);
        $text = str_replace("\n", '<br />', $text);
        return addslashes($text);
    }

    function store($post)
    {
        $data = $this->input->post->getArray();

        $data['misil'] = $this->input->get('misil', '', 'post', 'string', $this->input->get_ALLOWRAW);
        $data['misilonclick'] = $this->input->get('misilonclick', '', 'post', 'string', $this->input->get_ALLOWRAW);

        // Bind the form fields to the hello table

        $data['misil'] = $this->textnl($data['misil']);
        $data['misilonclick'] = $this->textnl($data['misilonclick']);
        $date = date("Y-m-d H:i:s", time());
        // Make sure the hello record is valid

        (trim($data['width_map_yandex']) !== '') ? $data['width_map_yandex'] = $data['width_map_yandex'] : $data['width_map_yandex'] = 500;
        (trim($data['height_map_yandex']) !== '') ? $data['height_map_yandex'] = $data['height_map_yandex'] : $data['height_map_yandex'] = 500;

        $lng = json_encode(array('longitude_map_yandex' => $data['longitude_map_yandex'], 'latitude_map_yandex' => $data['latitude_map_yandex']));
        $data['wih'] = json_encode(array($data['width'], $data['height']));
        // Store the web link table to the database

        //$id = $this->input->getInt('id');
        $app = Factory::getApplication();
        $user = $app->getIdentity(); // it's important to set the "0" otherwise your admin user information will be loaded
        if ($user->id > 0) {
            $user = $user->id;
        }
        $userimg = json_encode(array('smallfile'=>$data['smallfile'],'startfile'=>$data['startfile']));

        $db = $this->getDatabase();

        if (!$data['editmarket']) {
            $query = "INSERT INTO " . $db->quoteName('#__map_yandex_metki')
                . " (`name_marker`,`misil`,`misilonclick`,`city_map_yandex`, `street_map_yandex`, `checked_out`,`checked_out_time`,`ordering`,`published`,`hits`,`catid`,`params`,`yandexcoord`,`lng`,`id_map`,`deficon`,`whoadd`,`userimg`) VALUES
			('" . $data['name_marker'] . "','" . $data['misil'] . "','" . $data['misilonclick'] . "','" . $data['city_map_yandex'] . "', '" . $data['street_map_yandex'] . "', 0, '$date', 4, 1, 0, 1, '', '" . $data['yandexcoord'] . "','$lng', '" . $data['id_map'] . "', '" . $data['deficon'] . "', '" . $user . "', '" . $userimg . "')";
        } else {
            $query = "UPDATE " . $db->quoteName('#__map_yandex_metki')
                . " set " . $db->quoteName('name_marker') . " = '" . $data['name_marker']
                . "', " . $db->quoteName('misil') . " = '" . $data['misil']
                . "', " . $db->quoteName('misilonclick') . " = '" . $data['misilonclick']
                . "', " . $db->quoteName('city_map_yandex') . " = '" . $data['city_map_yandex']
                . "', " . $db->quoteName('street_map_yandex') . " = '" . $data['street_map_yandex']
                . "', " . $db->quoteName('yandexcoord') . " = '" . $data['yandexcoord']
                . "', " . $db->quoteName('lng') . " = '" . $lng
                . "', " . $db->quoteName('id_map') . " = '" . $data['id_map']
                . "', " . $db->quoteName('deficon') . " = '" . $data['deficon']
                . "', " . $db->quoteName('wih') . " = '" . $data['wih'];
                if(!empty($data['smallfile'] && !empty($data['startfile']))) {
                    $query  .= "', " . $db->quoteName('userimg') . " = '" . $userimg;
                }
            $query  .= "' WHERE " . $db->quoteName('id') . " =" . $data['id'];
        }

        $db->setQuery($query);
        if (!$db->execute()) {
            Factory::getApplication()->enqueueMessage($db->getError(),'error');

            return false;
        }

        return true;
    }

    function getMarker($cid)
    {

        $db = JFactory::getDBO();
        $query = ' SELECT * ' . ' FROM #__map_yandex_metki WHERE id=' . $cid;
        $query = $db->setQuery($query);
        $this->marker = $db->loadObjectList();

        return $this->marker;
    }

    function delete(&$post)
    {
        $cids = $this->input->get('cid', array(0), 'post', 'array');
        $cont = Factory::getContainer();
        $db = $cont->get('DatabaseDriver');

        if (\count($cids)) {
            $params = JComponentHelper::getParams('com_mapyandex');

            foreach ($cids as $cid) {

                $marker = $this->getMarker($cid);
                $userimg = json_decode($marker[0]->userimg);
                $userimgarr = (array) $userimg;
                array_push($userimgarr, str_replace('_s', '', $userimgarr['smallfile']));
                if (\count((array) $userimg) > 1) {

                    $this->success = array();
                    $this->info = array();
                    $i = 0;
                    foreach ($userimgarr as $file) {
                        ++$i;
                        $userpath = $params->get('userpathtoimg');

                        if (empty($userpath)) {

                            $userpath = '/images/mapyandex/yandexmarkerimg/';
                        }

                        if (JFile::exists($_SERVER['DOCUMENT_ROOT'] . JURI::root(true) . $userpath . $file)) {

                            $jp = JPath::getPermissions($_SERVER['DOCUMENT_ROOT'] . JURI::root(true) . $userpath . $file);
                            $ch = JPath::canChmod($_SERVER['DOCUMENT_ROOT'] . JURI::root(true) . $userpath . $file);

                            $jp = str_split($jp, 3);

                            if (strpos($jp[0], 'w')) {

                                if (JFile::delete($_SERVER['DOCUMENT_ROOT'] . JURI::root(true) . $userpath . $file)) {
                                    $this->success[] = 1;
                                    $this->info[] = $file;
                                } else {
                                    $this->success[] = 0;
                                    $this->info[] = $file;
                                }

                            } else {

                                //2 not perms
                                $this->success[] = 2;
                                $this->info[] = $file;
                                JError::raiseNotice(100, 'Ошибка файл "' . JURI::root(true) . $userpath . $file . '" не существует!');
                            }
                        } else {

                            $this->success[] = 0;
                            $this->info[] = $file;
                            Factory::getApplication()->enqueueMessage(Text::sprintf('COM_MAPYANDEX_ERROR_NO_FILE', JURI::root(true) . $userpath . $file),'error');
                        }
                        if ($i == 3) {
                            $query = 'DELETE FROM #__map_yandex_metki'
                                . ' WHERE id = ' . $cid;
                            $db->setQuery($query);
                            if (!$db->execute()) {
                                Factory::getApplication()->enqueueMessage($db->getError(),'error');
                            }
                        }
                    }

                } else {
                    $query = 'DELETE FROM #__map_yandex_metki'
                        . ' WHERE id = ' . $cid;
                    $db->setQuery($query);
                    if (!$db->execute()) {
                        JError::raiseWarning(500, $db->getError());
                    }
                }

            }
        }

        return true;
    }

}
