<?php
/*
 * @package Joomla 4.0
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Yandex Map Component
 * @copyright Copyright (C) Aleksandr Ermakov www.slyweb.ru
 */

namespace Slyweb\Component\Mapyandex\Administrator\Model;

// No direct access
use JFactory;
use Joomla\CMS\Factory;
use Joomla\CMS\MVC\Model\ListModel;
use JPagination;
use JTable;

\defined('_JEXEC') or die('Restricted access');

class RegionModel extends ListModel
{
    /**
     * Foobar ID
     *
     * @var int
     */
    var $_id;
    /**
     * Foobar data
     *
     * @var object
     */
    var $_foobar;
    var $_allroute;
    var $_metka;

    /**
     * @var mixed
     */
    private $db;

    /**
     * Constructor, builds object and determines the foobar ID
     */
    function __construct()
    {
        parent::__construct();
        // get the cid array from the default request hash
        $this->input = Factory::getApplication()->input;
        $id = $this->input->get('id', 3);
        $this->setId($id);
        $this->db  = Factory::getContainer()->get('DatabaseDriver');
    }

    /**
     * Method to get the record form.
     *
     * @param array $data Data for the form.
     * @param boolean $loadData True if the form is to load its own data (default case), false if not.
     * @return    mixed    A JForm object on success, false on failure
     * @since    2.5
     */
    public function getForm($data = array(), $loadData = true)
    {
        // Default opacity
        $map = $this->getMap();
        if (!empty($map->map_region_style)) {

            $def = json_decode($map->map_region_style);
        } else {
            $def[0] = 1;
        }
        $form = $this->loadForm('com_mapyandex.region', 'mapyandexroute', array('control' => 'jform', 'load_data' => $loadData));
        $form->setFieldAttribute('map_region_opacity', 'default', $def[0]);
        if (empty($form)) {
            return false;
        }

        return $form;

    }

    /**
     * Method to auto-populate the model state.
     * Note. Calling getState in this method will result in recursion.
     *
     * @since    1.6
     */
    protected function populateState($ordering = null, $direction = null)
    {
        // Initialise variables.
        $app = JFactory::getApplication('administrator');
        // Load the filter state.
        $search = $app->getUserStateFromRequest('filter.search', 'filter_search');
        $this->setState('filter.search', $search);
        // List state information.
        parent::populateState('a.id', 'asc');
    }


    /**
     * Method to get the data that should be injected in the form.
     *
     * @return    mixed    The data for the form.
     * @since    2.5
     */
    protected function loadFormData()
    {
        // Check the session for previously entered form data.
        $data = JFactory::getApplication()->getUserState('com_mapyandex.edit.region.data', array());
        if (empty($data)) {
            return false;
        }

        return $data;
    }

    /**
     * Обновление ID и данных
     *
     * @param int foobar ID
     */

    function setId($id)
    {
        $this->_id = $id;
        $this->_foobar = null;
    }

    /**
     * Получаем данные класса
     *
     * @return object
     */
    function getAllRoute()
    {

        // if foobar is not already loaded load it now
        if (!$this->_allroute) {

            $query = "SELECT * FROM " . $this->db->quoteName('#__map_yandex') . " WHERE " . $this->db->quoteName('map_type') . " = 'map'";
            $this->db->setQuery($query);
            $this->_allroute = $this->db->loadObjectList();
        }
        // return the foobar data
        return $this->_allroute;

    }

    /**
     * Получаем данные класса
     *
     * @return object
     */
    function getMap()
    {
        // if foobar is not already loaded load it now
        if (!$this->_map) {
            $this->db = $this->getDBO();
            $query = "SELECT * FROM " . $this->db->quoteName('#__map_yandex')
                . " WHERE " . $this->db->quoteName('id') . " = " . $this->_id . " AND " . $this->db->quoteName('map_type') . " = 'map'";
            $this->db->setQuery($query);
            $this->_map = $this->db->loadObject();
        }
        // return the foobar data
        return $this->_map;
    }

    function getMetka()
    {

        $this->db = $this->getDBO();
        $query = "SELECT * FROM " . $this->db->quoteName('#__map_yandex_metki')
            . " WHERE " . $this->db->quoteName('id_map') . " = " . $this->_id;
        $this->db->setQuery($query);
        $this->_metka = $this->db->loadObjectList();

        // return the foobar data
        return $this->_metka;

    }

    function textnl($text)
    {
        $text = str_replace("\r\n", "<br />", $text);
        $text = str_replace("\r", "<br />", $text);
        $text = str_replace("\n\n", '<p>', $text);
        $text = str_replace("\n", '<br />', $text);

        return addslashes($text);
    }

    /**
     * Returns a reference to the a Table object, always creating it.
     *
     * @param type    The table type to instantiate
     * @param string    A prefix for the table class name. Optional.
     * @param array    Configuration array for model. Optional.
     * @return    JTable    A database object
     * @since    2.5
     */
    public function getTable($type = 'MapYandexRoute', $prefix = 'Table', $config = array())
    {
        return JTable::getInstance($type, $prefix, $config);
    }


    /**
     * Method to store a record
     *
     * @access    public
     * @return    boolean    True on success
     */
    function store($post)
    {
        $row = $this->getTable();
        $data = $this->input->post->getArray();
        $data['misil'] = $this->input->getVar('misil', '', 'post', 'string', JREQUEST_ALLOWRAW);
        $data['misilonclick'] = $this->input->getVar('misilonclick', '', 'post', 'string', JREQUEST_ALLOWRAW);

        $data['jform'] = $this->input->getVar('jform', '', 'post', 'string', JREQUEST_ALLOWRAW);
        // Bind the form fields to the hello table

        if (!$row->bind($data)) {
            $this->setError($this->_db->getErrorMsg());

            return false;
        }
        //preg_match_all('@@',$this->textnl($data['allroutemap']),$matches);
        $lng = json_encode(array('longitude_map_yandex' => $data['longitude_map_yandex'], 'latitude_map_yandex' => $data['latitude_map_yandex']));
        $el = json_encode($data['name_region_yandex']);
        $style = json_encode(array($data['jform']['map_region_opacity'], $data['jform']['color_map_region']));
        // Store the web link table to the database

        $query = "UPDATE #__map_yandex set " . $this->db->quoteName('region_map_yandex') . " = '" . $this->textnl($el)
            . "', " . $this->db->quoteName('map_region_style') . " = '" . $style . "' WHERE " . $this->db->quoteName('id') . " = " . $data['id'];
        $this->db->setQuery($query);
        if (!$this->db->execute()) {
            $this->setError($this->db->getError());

            return false;
        }

        return true;
    }

    /**
     * Method to delete record(s)
     *
     * @access    public
     * @return    boolean    True on success
     */
    function delete(&$post)
    {
        $cids = $this->input->getVar('cid', array(0), 'post', 'array');

        $row = $this->getTable();

        if (\count($cids)) {
            foreach ($cids as $cid) {
                if (!$row->delete($cid)) {
                    $this->setError($row->getErrorMsg());

                    return false;
                }
            }
        }

        return true;
    }


    /**
     * @возвращает список строк в файл view.html.php
     */

    function getReviews()
    {
        $app = JFactory::getApplication();
        $limit = $this->input->getVar('limit',$app->getCfg('list_limit'));

        $limitstart = $this->input->getVar('limitstart', 0);

        $query = "SELECT count(*) FROM #__map_yandex";
        $this->db->setQuery($query);
        $total = $this->db->loadResult();
        $query = "SELECT * FROM #__map_yandex";
        $this->db->setQuery($query, $limitstart, $limit);
        //$rows = $this->db->loadObjectList();
        if (!$this->db->execute()) {
            echo $this->db->stderr();
            return false;
        }
        return $this->pageNav = new JPagination($total, $limitstart, $limit);

    }
}
