<?php
/*
 * @package Joomla 4.x
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Yandex Map Component
 * @copyright Copyright (C) Aleksandr Ermakov www.slyweb.ru
 */

namespace Slyweb\Component\Mapyandex\Administrator\View\Allmaps;

use Exception;
use JComponentHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Helper\ContentHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\Pagination\Pagination;
use Joomla\CMS\Toolbar\Toolbar;
use JToolbarHelper;

\defined('_JEXEC') or die('Restricted access');
// import the JView class

/**
* Foobar View
*/
class HtmlView extends BaseHtmlView
{
    /**
     * An array of items
     *
     * @var  array
     */
    protected $items;

    /**
     * The pagination object
     *
     * @var  Pagination
     */
    protected $pagination;

    /**
     * The model state
     *
     * @var  object
     */
    protected $state;

    /**
     * Flag if an association exists
     *
     * @var  boolean
     */
    protected $assoc;

    /**
     * Form object for search filters
     *
     * @var  \Joomla\CMS\Form\Form
     */
    public $filterForm;

    /**
     * The active search filters
     *
     * @var  array
     */
    public $activeFilters;

    /**
     * Is this view an Empty State
     *
     * @var  boolean
     * @since 4.0.0
     */
    private $isEmptyState = false;

    /**
     * Hellos view display method
     *
     * @return void
     *
     * @throws Exception
     */
	function display($tpl = null)
	{

        $this->pagination    = $this->get('Pagination');
        $this->state         = $this->get('State');
        $this->filterForm    = $this->get('FilterForm');
        $this->activeFilters = $this->get('ActiveFilters');
        $this->form	= $this->get('Form');

        // add the CSS to the document

        try {
            $wa = Factory::getApplication()->getDocument()->getWebAssetManager();
            $wa->useStyle('mapyandex');
        } catch (Exception $e) {
            var_dump($e->getMessage());
        }

        $input = Factory::getApplication()->input;
		$data['layout'] = $input->get('layout');
		$data['task']   = $input->get('task');

		// interrogate the model
		//$this->maps = $this->get('AllMaps');
        if($data['layout'] != 'form') {
            $this->maps = $this->get('Items');
        }

		if($data['layout'] == 'form' && $data['task'] != 'add' && !empty($this->map)) $this->map = $this->map[0];

		if(empty($this->maps) || $data['layout'] == 'form') {
            $this->map = $this->get('DefaultSettings');
        }


		$params = JComponentHelper::getParams('com_mapyandex');
		$this->apikey = $params->get('key', '');


        $this->addToolbar();
		parent::display($tpl);
	}

    /**
     * Add the page title and toolbar.
     *
     * @return  void
     *
     * @throws \Exception
     * @since   1.6
     */
    protected function addToolbar()
    {
        $input = Factory::getApplication()->input;
        $layout = $input->get('layout');

        $categoryId = $this->state->get('filter.category_id');
        $component  = $this->state->get('filter.component');
        $section    = $this->state->get('filter.section');
        $canDo      = ContentHelper::getActions('com_mapyandex', 'map', $categoryId);
        $user       = Factory::getApplication()->getIdentity();

        // Get the toolbar object instance
        $toolbar = Toolbar::getInstance('toolbar');

        // Avoid nonsense situation.
        if ($component == 'com_mapyandex') {
            return;
        }

        // Need to load the menu language file as mod_menu hasn't been loaded yet.
        $lang = Factory::getLanguage();
        $lang->load($component, JPATH_BASE) || $lang->load($component, JPATH_ADMINISTRATOR . '/components/' . $component);

		if($layout == 'form') {
		    JToolBarHelper::title(Text::_('COM_MAPYANDEX_YANDEXNEWMAP'), 'allmaps');
		} else {
			JToolBarHelper::title(Text::_('COM_MAPYANDEX_NAMECOMPONENT'), 'allmaps');

		}

        if ($canDo->get('core.create') || \count($user->getAuthorisedCategories($component, 'core.create')) > 0) {
            if($layout == 'form') {
                $toolbar->save('allmaps.save');
            } else {
                $toolbar->addNew('allmaps.add');
            }

        }

        if (!$this->isEmptyState && ($canDo->get('core.edit.state') || $user->authorise('core.admin'))) {
            $dropdown = $toolbar->dropdownButton('status-group')
                ->text('JTOOLBAR_CHANGE_STATUS')
                ->toggleSplit(false)
                ->icon('icon-ellipsis-h')
                ->buttonClass('btn btn-action')
                ->listCheck(true);
         if($layout != 'form') {
             $childBar = $dropdown->getChildToolbar();
             if ($user->authorise('core.delete')) {
                 $childBar->delete('allmaps.remove')->listCheck(true);
             }

             if ($canDo->get('core.edit')) {
                 $childBar->publish('allmaps.publish')->listCheck(true);
                 $childBar->unpublish('allmaps.unpublish')->listCheck(true);
             }

             if ($user->authorise('core.admin')) {
                 $childBar->checkin('allmaps.checkin')->listCheck(true);
             }

             // Add a batch button
             if (
                 $canDo->get('core.create')
                 && $canDo->get('core.edit')
                 && $canDo->get('core.edit.state')
             ) {
                 $childBar->popupButton('batch')
                     ->text('JTOOLBAR_BATCH')
                     ->selector('collapseModal')
                     ->listCheck(true);
             }
         }
        }

        /*if (!$this->isEmptyState && $canDo->get('core.admin')) {
            $toolbar->standardButton('refresh')
                ->text('JTOOLBAR_REBUILD')
                ->task('allmaps.rebuild');
        }*/

        if ($user->authorise('core.admin', 'com_mapyandex') || $user->authorise('core.options', 'com_mapyandex')) {
            $toolbar->preferences('com_mapyandex');
        }

    }
}

?>
