<?php
/*
 * @package Joomla 4.x
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Yandex Map Component
 * @copyright Copyright (C) Aleksandr Ermakov www.slyweb.ru
 */

namespace Slyweb\Component\Mapyandex\Administrator\View\Metki;

use Exception;
use JComponentHelper;
use JFactory;
use JHtml;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\Pagination\Pagination;
use Joomla\CMS\Toolbar\Toolbar;
use Joomla\CMS\Toolbar\ToolbarHelper;
use Joomla\Component\Content\Administrator\Helper\ContentHelper;
use Slyweb\Component\Mapyandex\Administrator\Helper\MapyandexHelper;
use JToolbarHelper;
use JUri;

\defined('_JEXEC') or die('Restricted access');
// import the JView class

/**
 * Foobar View
 */
class HtmlView extends BaseHtmlView
{
    /**
     * An array of items
     *
     * @var  array
     */
    protected $items;

    /**
     * The pagination object
     *
     * @var  Pagination
     */
    protected $pagination;

    /**
     * The model state
     *
     * @var  object
     */
    protected $state;

    /**
     * Flag if an association exists
     *
     * @var  boolean
     */
    protected $assoc;

    /**
     * Form object for search filters
     *
     * @var  \Joomla\CMS\Form\Form
     */
    public $filterForm;

    /**
     * The active search filters
     *
     * @var  array
     */
    public $activeFilters;

    /**
     * Is this view an Empty State
     *
     * @var  boolean
     * @since 4.0.0
     */
    private $isEmptyState = false;

    /**
     * Hellos view display method
     *
     * @return void
     **/

    function display($tpl = null)
    {
        $this->filterForm = $this->get('FilterForm');
        $this->activeFilters = $this->get('ActiveFilters');
        $this->state = $this->get('State');

        // add the CSS to the document
        try {
            $wa = Factory::getApplication()->getDocument()->getWebAssetManager();
            $wa->useStyle('mapyandex');
        } catch (Exception $e) {
            dump($e->getMessage() . ' in ' . __FILE__ . ' on line ' . __LINE__);
        }
        $this->form = $this->get('Form');

        $this->addToolbar();
        $input = Factory::getApplication()->input;
        $layout = $input->get('layout');
        if($layout != 'formedit') {
            $this->metki = $this->get('Items');
        }

        $editmarker = $this->get('Editmarker');
        $this->editmarker = $editmarker;
        $pageNav = $this->get('Reviews');
        $this->pageNav = $pageNav;
        $this->params = JComponentHelper::getParams('com_mapyandex');

        if (\count($this->editmarker) > 0) {
            if ($this->editmarker['0']) {
                $cur_id_map = $this->editmarker[0];
                $id_map = $cur_id_map->id_map;
                $allmaps = $this->fetchElement($id_map);
                $this->allmaps = $allmaps;
            }
        } else {
            $this->allmaps = $this->fetchElement();
        }

        $this->canwrite = MapYandexHelper::canWrite();
        parent::display($tpl);

    }

    /**
     * Add the page title and toolbar.
     *
     * @return  void
     *
     * @throws \Exception
     * @since   1.6
     */
    protected function addToolbar()
    {
        $input = Factory::getApplication()->input;
        // Get the toolbar object instance
        $toolbar = Toolbar::getInstance('toolbar');
        ToolbarHelper::title(Text::_('COM_CONTENT_METKI_TITLE'), 'copy article');
        $layout = $input->get('layout');
        if ($layout == 'form') {
            $toolbar->save('metki.save');
        } elseif ($layout == 'formedit') {
            $toolbar->save('metki.save');
            $toolbar->apply('metki.apply');
            $toolbar->cancel('metki.cancel');
        } else {
            $user = $this->getCurrentUser();
            $categoryId = $this->state->get('filter.category_id');
            $canDo      = \Joomla\CMS\Helper\ContentHelper::getActions('com_mapyandex', 'map', $categoryId);
            if ($canDo->get('core.create') || \count($user->getAuthorisedCategories('com_mapyandex', 'core.create')) > 0) {
                $toolbar->addNew('metki.add');

                JToolBarHelper::deleteList(Text::_('COM_MAPYANDEX_DELETE_CONFIRM'), 'remove');
            }
        }
    }

    function fetchElement($id_map = null)
    {
        $db = JFactory::getDBO();
        $query = "SELECT * FROM " . $db->quoteName('#__map_yandex') . " WHERE map_type='map'";
        $db->setQuery($query);
        $options = $db->loadObjectList();

        return JHTML::_('select.genericlist', $options, 'id_map', 'class="inputbox"', 'id', 'name_map_yandex', $id_map, 'name_map_yandex');
    }
}

?>
