<?php
/*
 * @package Joomla 4.x
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Yandex Map Component
 * @copyright Copyright (C) Aleksandr Ermakov www.slyweb.ru
 */

defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Button\PublishedButton;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Layout\LayoutHelper;
use Joomla\CMS\Session\Session;

/** @var \Joomla\CMS\WebAsset\WebAssetManager $wa */
$wa = $this->document->getWebAssetManager();
$wa->useScript('table.columns')
    ->useScript('multiselect');


$extension = $this->escape($this->state->get('filter.extension'));
$listOrder = $this->escape($this->state->get('list.ordering'));
$listDirn = $this->escape($this->state->get('list.direction'));

$saveOrder = ($listOrder == 'a.id' && strtolower($listDirn) == 'asc');

if ($saveOrder && !empty($this->maps)) {
    $saveOrderingUrl = 'index.php?option=com_categories&task=categories.saveOrderAjax&tmpl=component&' . Session::getFormToken() . '=1';
    HTMLHelper::_('draggablelist.draggable');
}
HTMLHelper::_('behavior.core');
JHtml::_('behavior.multiselect');
JHtml::_('dropdown.init');
?>

<form action="<?php JRoute::_('index.php?option=com_mapyandex&extension=' . $this->state->get('filter.extension')); ?>" method="post" id="adminForm" name="adminForm">
    <div class="row">
        <div class="col-md-12">
            <div id="j-main-container" class="j-main-container">
                <?php
                // Search tools bar
                echo LayoutHelper::render('joomla.searchtools.default', array('view' => $this));
                ?>
                <?php if (empty($this->maps)) : ?>
                    <div class="alert alert-info">
                        <span class="icon-info-circle" aria-hidden="true"></span><span
                                class="visually-hidden"><?php echo Text::_('INFO'); ?></span>
                        <?php echo Text::_('JGLOBAL_NO_MATCHING_RESULTS'); ?>
                    </div>
                <?php else : ?>
                    <table class="table" id="categoryList">
                        <thead>
                        <tr>
                            <th class="w-1 text-center">
                                <?php echo HTMLHelper::_('grid.checkall'); ?>
                            </th>
                            <th scope="col" class="w-1 text-center d-none d-md-table-cell">
                                <?php echo HTMLHelper::_('searchtools.sort', '', 'a.id', $listDirn, $listOrder, null, 'asc', 'JGRID_HEADING_ORDERING', 'icon-sort'); ?>
                            </th>
                            <th scope="col" class="w-1 text-center">
                                <?php echo HTMLHelper::_('searchtools.sort', 'JSTATUS', 'a.published', $listDirn, $listOrder); ?>
                            </th>
                            <th scope="col">
                                <?php echo HTMLHelper::_('searchtools.sort', 'COM_MAPYANDEX_NAMEMAP', 'a.name_map_yandex', $listDirn, $listOrder); ?>
                            </th>
                            <th scope="col">
                                <?php echo JText::_('COM_MAPYANDEX_DESCRIPTIONOFTAG'); ?>
                            </th>
                            <th scope="col">
                                <?php echo HTMLHelper::_('searchtools.sort', 'COM_MAPYANDEX_HITS', 'a.hits', $listDirn, $listOrder); ?>
                            </th>
                            <th scope="col">
                                <?php echo JText::_('COM_MAPYANDEX_YMCODE'); ?>
                            </th>
                            <th scope="col">
                                <?php echo JText::_('COM_MAPYANDEX_TYPE'); ?>
                            </th>
                            <th scope="col">
                                <?php echo JText::_('COM_MAPYANDEX_TIME'); ?>
                            </th>
                        </tr>
                        </thead>
                        <tbody <?php if ($saveOrder) :
                            ?> class="js-draggable" data-url="<?php echo $saveOrderingUrl; ?>" data-direction="<?php echo strtolower($listDirn); ?>" data-nested="false"<?php
                        endif; ?>>
                        <?php
                        $k = 0;

                        for ($i = 0, $n = count($this->maps); $i < $n; $i++) {
                            $row = $this->maps[$i];
                            $checked = JHTML::_('grid.id', $i, $row->id);
                            if ($row->map_type == 'calculator') {
                                $link = JRoute::_('index.php?option=com_mapyandex&view=calculator&layout=formedit&id=' . $row->id);
                            } else {
                                $link = JRoute::_('index.php?option=com_mapyandex&view=map&layout=form&id=' . $row->id);
                            }

                            ?>
                            <tr class="<?php echo "row$k"; ?>">
                                <td>
                                    <?php echo $checked; ?>
                                </td>

                                <td>
                                    <?php echo $row->id; ?>
                                </td>
                                <td class="article-status text-center">
                                    <?php
                                    $options = [
                                        'task_prefix' => '',
                                        'id' => 'state-' . $row->id,
                                     ];

                                    echo (new PublishedButton())->render((int) $row->published, $i, $options);
                                    ?>
                                </td>

                                <td>
                                    <a href="<?php echo $link; ?>"><?php echo $row->name_map_yandex; ?></a>
                                </td>
                                <td>
                                    <a href="<?php echo $link; ?>"><?php echo $row->misil; ?></a>
                                </td>
                                <td style="text-align:center;">
                                    <?php echo $row->hits; ?>
                                </td>
                                <td style="text-align:center;">
                                    <?php
                                    if ($row->map_type == 'calculator') {
                                        echo '{mapyandex_calculator_id=' . $row->id . '}';
                                    } else {
                                        echo '{mapyandex_id=' . $row->id . '}';
                                    }

                                    ?>
                                </td>
                                <td style="text-align:center;">
                                    <?php
                                    $path = 'administrator/components/com_mapyandex/assets/images/';
                                    if ($row->map_type == 'calculator') {
                                        echo JHTML::_('image', $path . 'calculator.png', '', 'style="margin-bottom: 3px;"');
                                    } else {
                                        echo JHTML::_('image', $path . 'map.png', '', 'style="margin-bottom: 3px;"');
                                    }
                                    ?>
                                </td>

                                <td style="text-align:center;">
                                    <?php
                                        echo JHTML::_('date', $row->checked_out_time);
                                    ?>
                                </td>
                            </tr>
                            <?php
                            $k = 1 - $k;
                        }
                        ?>
                        </tbody>
                        <tr>
                            <td colspan="9"><?php echo $this->pagination->getListFooter(); ?></td>
                        </tr>
                    </table>

                <?php endif; ?>

            </div>
        </div>

    </div>
    </div>
    <input type="hidden" name="option" value="com_mapyandex" />
    <input type="hidden" name="task" value="" />
    <input type="hidden" name="boxchecked" value="0">
    <input type="hidden" name="controller" value="allmaps" />
    <input type="hidden" name="view" value="allmaps" />

    <input type="hidden" name="extension" value="<?php echo $extension; ?>">

    <?php echo HTMLHelper::_('form.token'); ?>
</form>
